/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.sensor.fritzmeier;

import java.awt.Image;
import java.io.IOException;
import java.util.logging.Logger;
import nl.cloudfarming.client.geoviewer.BaseLayer;
import nl.cloudfarming.client.geoviewer.SimpleLayer;
import nl.cloudfarming.client.sensor.SensorDataObject;
import nl.cloudfarming.client.sensor.SensorFileNode;
import nl.cloudfarming.client.sensor.SensorProcessor;
import org.netbeans.core.spi.multiview.MultiViewElement;
import org.netbeans.core.spi.multiview.text.MultiViewEditorElement;
import org.openide.filesystems.FileObject;
import org.openide.loaders.DataObjectExistsException;
import org.openide.loaders.MultiFileLoader;
import org.openide.nodes.Node;
import org.openide.util.HelpCtx;
import org.openide.util.ImageUtilities;
import org.openide.util.Lookup;
import org.openide.util.NbBundle.Messages;
import org.openide.windows.TopComponent;

public class FritzmeierDataObject extends SensorDataObject {

    public static final String MIME_TYPE = "text/csv-fritzmeier";
    public static final String ICON_BASE = "nl/cloudfarming/client/sensor/fritzmeier/fritzmeier-file-icon.png";
    private static final Logger LOG = Logger.getLogger("nl.cloudfarming.client.sensor.fritzmeier.FritzmeierDataObject");
    private FritzmeierFileProcessor processor = null;

    public FritzmeierDataObject(FileObject pf, MultiFileLoader loader) throws DataObjectExistsException, IOException {
        super(pf, loader);

        LOG.info("FritzmeierDataObject constructor");
        registerEditor(MIME_TYPE, true);
    }

    @Override
    protected int associateLookup() {
        return 1;
    }

    @Override
    public HelpCtx getHelpCtx() {
        return new HelpCtx("nl.cloudfarming.client.sensor.fritzmeier.about");
    }

    @MultiViewElement.Registration(displayName = "#LBL_Fritzmeier_EDITOR",
    iconBase = ICON_BASE,
    mimeType = MIME_TYPE,
    persistenceType = TopComponent.PERSISTENCE_ONLY_OPENED,
    preferredID = "Fritzmeier",
    position = 200)
    @Messages("LBL_Fritzmeier_EDITOR=Source")
    public static MultiViewEditorElement createEditor(Lookup lkp) {
        return new MultiViewEditorElement(lkp);
    }

    @Override
    protected Node createNodeDelegate() {
        return new FritzMeierNode(super.createNodeDelegate());
    }

    @Override
    protected SensorProcessor getProcessor() {
        if (processor == null) {
            processor = new FritzmeierFileProcessor(this);
        }
        return processor;
    }

    /**
     * Node for the FritzMeier
     */
    private class FritzMeierNode extends SensorFileNode {

        public FritzMeierNode(Node original) {
            super(original, FritzmeierDataObject.this, new BaseLayer(getPalette(), original.getDisplayName()));
        }

        @Override
        public Image getIcon(int type) {
            return ImageUtilities.loadImage(ICON_BASE);
        }
    }
}
